==> webkit2gtk_2.13.4.orig.tar.xz: webkitgtk-2.13.4/Source/WebInspectorUI/UserInterface/Models/StructureDescription.js <==
/*
 * Copyright (C) 2015 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

WebInspector.StructureDescription = class StructureDescription extends WebInspector.Object
{
    constructor(fields, optionalFields, constructorName, prototypeStructure, imprecise)
    {
        super();

        console.assert(!fields || fields.every((x) => typeof x === "string"));
        console.assert(!optionalFields || optionalFields.every((x) => typeof x === "string"));
        console.assert(!constructorName || typeof constructorName === "string");
        console.assert(!prototypeStructure || prototypeStructure instanceof WebInspector.StructureDescription);

        this._fields = fields || null;
        this._optionalFields = optionalFields || null;
        this._constructorName = constructorName || "";
        this._prototypeStructure = prototypeStructure || null;
        this._imprecise = imprecise || false;
    }

    // Static

    // Runtime.StructureDescription.
    static fromPayload(payload)
    {
        if (payload.prototypeStructure)
            payload.prototypeStructure = WebInspector.StructureDescription.fromPayload(payload.prototypeStructure);

        return new WebInspector.StructureDescription(payload.fields, payload.optionalFields, payload.constructorName, payload.prototypeStructure, payload.imprecise);
    }

    // Public

    get fields()
    {
        return this._fields;
    }

    get optionalFields()
    {
        return this._optionalFields;
    }

    get constructorName()
    {
        return this._constructorName;
    }

    get prototypeStructure()
    {
        return this._prototypeStructure;
    }

    get imprecise()
    {
        return this._imprecise;
    }
};

==> webkit2gtk_2.17.5.orig.tar.xz: webkitgtk-2.17.5/Source/WebInspectorUI/UserInterface/Models/StructureDescription.js <==
/*
 * Copyright (C) 2015 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

WebInspector.StructureDescription = class StructureDescription
{
    constructor(fields, optionalFields, constructorName, prototypeStructure, imprecise)
    {
        console.assert(!fields || fields.every((x) => typeof x === "string"));
        console.assert(!optionalFields || optionalFields.every((x) => typeof x === "string"));
        console.assert(!constructorName || typeof constructorName === "string");
        console.assert(!prototypeStructure || prototypeStructure instanceof WebInspector.StructureDescription);

        this._fields = fields || null;
        this._optionalFields = optionalFields || null;
        this._constructorName = constructorName || "";
        this._prototypeStructure = prototypeStructure || null;
        this._imprecise = imprecise || false;
    }

    // Static

    // Runtime.StructureDescription.
    static fromPayload(payload)
    {
        if (payload.prototypeStructure)
            payload.prototypeStructure = WebInspector.StructureDescription.fromPayload(payload.prototypeStructure);

        return new WebInspector.StructureDescription(payload.fields, payload.optionalFields, payload.constructorName, payload.prototypeStructure, payload.imprecise);
    }

    // Public

    get fields() { return this._fields; }
    get optionalFields() { return this._optionalFields; }
    get constructorName() { return this._constructorName; }
    get prototypeStructure() { return this._prototypeStructure; }
    get imprecise() { return this._imprecise; }
};
